==> jc-1.4.0.tar.gz: polyglot/frontend/ParserPass.h <==
// public class polyglot.frontend.ParserPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 7b121f88b00c88b6 polyglot_frontend_ParserPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_ParserPass_H_
#define _JC_polyglot_frontend_ParserPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Compiler$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_ParserPass$sub_refs	_jc_polyglot_frontend_ParserPass$sub_refs;
typedef struct _jc_polyglot_frontend_ParserPass$sub_nonrefs	_jc_polyglot_frontend_ParserPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_ParserPass$refs	_jc_polyglot_frontend_ParserPass$refs;
typedef struct _jc_polyglot_frontend_ParserPass$nonrefs	_jc_polyglot_frontend_ParserPass$nonrefs;
typedef struct _jc_polyglot_frontend_ParserPass$object	_jc_polyglot_frontend_ParserPass$object;

typedef const struct _jc_polyglot_frontend_ParserPass$vmethods	_jc_polyglot_frontend_ParserPass$vmethods;
typedef const struct _jc_polyglot_frontend_ParserPass$vtable	_jc_polyglot_frontend_ParserPass$vtable;
typedef const struct _jc_polyglot_frontend_ParserPass$vtype	_jc_polyglot_frontend_ParserPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_ParserPass$method$_init$1f66c76d5e7819ce(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_polyglot_frontend_Job$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_ParserPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_ParserPass$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_ParserPass$method_info$run$1ec62afce18bd5ee;
extern _jc_method _jc_polyglot_frontend_ParserPass$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_ParserPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_ParserPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_ParserPass$vmethods	polyglot_frontend_ParserPass;
};

// Vtype
struct _jc_polyglot_frontend_ParserPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_ParserPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_ParserPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_frontend_Compiler$object	*compiler;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_ParserPass$refs {
    _jc_polyglot_frontend_ParserPass$sub_refs	polyglot_frontend_ParserPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_ParserPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_ParserPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_ParserPass$sub_nonrefs	polyglot_frontend_ParserPass;
};

// Object instance structure
struct _jc_polyglot_frontend_ParserPass$object {
	_jc_polyglot_frontend_ParserPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_ParserPass$vtype	*vtype;
	_jc_polyglot_frontend_ParserPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_ParserPass$vtype _jc_polyglot_frontend_ParserPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_ParserPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_ParserPass$class_object;

#endif	/* _JC_polyglot_frontend_ParserPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/ParserPass.h <==
// public class polyglot.frontend.ParserPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 7b121f88b00c88b6 polyglot_frontend_ParserPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_ParserPass_H_
#define _JC_polyglot_frontend_ParserPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Compiler$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_ParserPass$sub_refs	_jc_polyglot_frontend_ParserPass$sub_refs;
typedef struct _jc_polyglot_frontend_ParserPass$sub_nonrefs	_jc_polyglot_frontend_ParserPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_ParserPass$refs	_jc_polyglot_frontend_ParserPass$refs;
typedef struct _jc_polyglot_frontend_ParserPass$nonrefs	_jc_polyglot_frontend_ParserPass$nonrefs;
typedef struct _jc_polyglot_frontend_ParserPass$object	_jc_polyglot_frontend_ParserPass$object;

typedef const struct _jc_polyglot_frontend_ParserPass$vmethods	_jc_polyglot_frontend_ParserPass$vmethods;
typedef const struct _jc_polyglot_frontend_ParserPass$vtable	_jc_polyglot_frontend_ParserPass$vtable;
typedef const struct _jc_polyglot_frontend_ParserPass$vtype	_jc_polyglot_frontend_ParserPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_ParserPass$method$_init$1f66c76d5e7819ce(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_ParserPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_ParserPass$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_ParserPass$method_info$run$1ec62afce18bd5ee;
extern _jc_method _jc_polyglot_frontend_ParserPass$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_ParserPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_ParserPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_ParserPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_ParserPass$vmethods	polyglot_frontend_ParserPass;
};

// Vtype
struct _jc_polyglot_frontend_ParserPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_ParserPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_ParserPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_frontend_Compiler$object	*compiler;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_ParserPass$refs {
    _jc_polyglot_frontend_ParserPass$sub_refs	polyglot_frontend_ParserPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_ParserPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_ParserPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_ParserPass$sub_nonrefs	polyglot_frontend_ParserPass;
};

// Object instance structure
struct _jc_polyglot_frontend_ParserPass$object {
	_jc_polyglot_frontend_ParserPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_ParserPass$vtype	*vtype;
	_jc_polyglot_frontend_ParserPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_ParserPass$vtype _jc_polyglot_frontend_ParserPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_ParserPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_ParserPass$class_object;

#endif	/* _JC_polyglot_frontend_ParserPass_H_ */
